==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Apagar apenas as ligações que são recebidas',
	'bouton_effacer_statistiques' => 'Apagar todas as estatísticas',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evolução das visitas <br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Exibir a distribuição actual',
	'icone_repartition_visites' => 'Distribuição das visitas',
	'icone_statistiques_visites' => 'Estatísticas de visitas',
	'info_affichier_visites_articles_plus_visites' => 'Exibir as visitas para <b>os artigos mais visitados desde o início :</b>',
	'info_comment_lire_tableau' => 'Como ler este quadro',
	'info_forum_statistiques' => 'Estatísticas das visitas',
	'info_popularite_2' => 'popularidade do sítio :',
	'info_popularite_3' => 'popularidade : @popularite@ ; visitas : @visites@',
	'info_popularite_5' => 'popularidade :',
	'info_previsions' => 'previsões :',
	'info_question_vignettes_referer' => 'Quando consultar as estatísticas, pode ver uma pré-visualização de qualquer sítio de origem das visitas.',
	'info_question_vignettes_referer_oui' => 'Exibir as capturas de ecrã dos sítios de origem das visitas',
	'info_visites' => 'visitas :',
	'info_visites_plus_populaires' => 'Exibir as visitas para <b>os artigos mais populares</b> e para <b>os últimos artigos publicados :</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir as estatísticas das visitas',

	// O
	'onglet_origine_visites' => 'Origem das visitas',
	'onglet_repartition_debut' => 'desde o início',
	'onglet_repartition_lang' => 'Distribuição por idiomas',

	// R
	'resume' => 'Resumo',

	// T
	'texte_admin_effacer_stats' => 'Esta opção apaga todas as estatísticas das visitas ao seu sítio web, incluindo a popularidade dos artigos.',
	'texte_admin_effacer_toutes_stats' => 'O primeiro botão apaga todas as estatísticas: visitas, popularidade dos artigos e ligações recebidas.',
	'texte_comment_lire_tableau' => 'O lugar do artigo,
na classificação por popularidade, é indicado na margem ; a popularidade do artigo (uma estimativa do número de visitas diárias que receberá se o ritmo actual de consulta se mantiver) e o número de visitas recebidas desde o início são exibidos no balão que aparece quando o rato passa sobre o título.',
	'texte_signification' => 'As barras escuras representam as entradas acumuladas (total das sub-rubricas), as barras claras o número de visitas para cada rubrica.',
	'titre_evolution_visite' => 'Evolução das visitas',
	'titre_liens_entrants' => 'Ligações a entrar',
	'titre_page_statistiques' => 'Estatísticas por rubricas',
	'titre_page_statistiques_visites' => 'Estatísticas das visitas',

	// V
	'visites_journalieres' => 'Número de visitas por dia',
	'visites_mensuelles' => 'Número de visitas por mês'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Apagar apenas as ligações que são recebidas',
	'bouton_effacer_statistiques' => 'Apagar todas as estatísticas',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evolução das visitas <br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Exibir a distribuição actual',
	'icone_repartition_visites' => 'Distribuição das visitas',
	'icone_statistiques_visites' => 'Estatísticas de visitas',
	'info_affichier_visites_articles_plus_visites' => 'Exibir as visitas para <b>os artigos mais visitados desde o início :</b>',
	'info_comment_lire_tableau' => 'Como ler este quadro',
	'info_forum_statistiques' => 'Estatísticas das visitas',
	'info_popularite_2' => 'popularidade do sítio :',
	'info_popularite_3' => 'popularidade : @popularite@ ; visitas : @visites@',
	'info_popularite_5' => 'popularidade :',
	'info_previsions' => 'previsões :',
	'info_question_vignettes_referer' => 'Quando consultar as estatísticas, pode ver uma pré-visualização de qualquer sítio de origem das visitas.', # MODIF
	'info_question_vignettes_referer_oui' => 'Exibir as capturas de ecrã dos sítios de origem das visitas',
	'info_visites' => 'visitas :',
	'info_visites_plus_populaires' => 'Exibir as visitas para <b>os artigos mais populares</b> e para <b>os últimos artigos publicados :</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir as estatísticas das visitas',

	// O
	'onglet_origine_visites' => 'Origem das visitas',
	'onglet_repartition_debut' => 'desde o início',
	'onglet_repartition_lang' => 'Distribuição por idiomas',

	// R
	'resume' => 'Resumo',

	// T
	'texte_admin_effacer_stats' => 'Esta opção apaga todas as estatísticas das visitas ao seu sítio web, incluindo a popularidade dos artigos.',
	'texte_admin_effacer_toutes_stats' => 'O primeiro botão apaga todas as estatísticas: visitas, popularidade dos artigos e ligações recebidas.',
	'texte_comment_lire_tableau' => 'O lugar do artigo,
na classificação por popularidade, é indicado na margem ; a popularidade do artigo (uma estimativa do número de visitas diárias que receberá se o ritmo actual de consulta se mantiver) e o número de visitas recebidas desde o início são exibidos no balão que aparece quando o rato passa sobre o título.',
	'texte_signification' => 'As barras escuras representam as entradas acumuladas (total das sub-rubricas), as barras claras o número de visitas para cada rubrica.',
	'titre_evolution_visite' => 'Evolução das visitas',
	'titre_liens_entrants' => 'Ligações a entrar',
	'titre_page_statistiques' => 'Estatísticas por rubricas',
	'titre_page_statistiques_visites' => 'Estatísticas das visitas',

	// V
	'visites' => 'Visitas',
	'visites_journalieres' => 'Número de visitas por dia',
	'visites_mensuelles' => 'Número de visitas por mês'
);
